@@ -1,7 +1,4 @@
 import os
-import json
-import random
-import tempfile
 import tifffile
 import numpy as np
 from PIL import Image
@@ -17,22 +14,13 @@ try:
 except ImportError:
     print('Install the scipy package to work with matlab files')
 
-from .abraia import Abraia
-
-tempdir = tempfile.gettempdir()
+from .client import Abraia, tempdir
 
 
 class Multiple(Abraia):
     def __init__(self, folder=''):
         super(Multiple, self).__init__()
 
-    def cache_file(self, path):
-        dest = os.path.join(tempdir, path)
-        if not os.path.exists(dest):
-            os.makedirs(os.path.dirname(dest), exist_ok=True)
-            self.download_file(path, dest)
-        return dest
-
     def load_header(self, path):
         dest = self.cache_file(path)
         return spectral.io.envi.read_envi_header(dest)
@@ -99,31 +87,4 @@ class Multiple(Abraia):
         else:
             Image.fromarray(img).save(src)
             return self.upload_file(src, path)
-
-    def load_json(self, path):
-        return json.loads(self.load_file(path))
-
-    def save_json(self, path, values):
-        return self.save_file(path, json.dumps(values))
-
-    def load_dataset(self, dataset, shuffle=True):
-        paths, labels = [], []
-        if self.check_file(f"{dataset}/annotations.json"):
-            annotations = self.load_json(f"{dataset}/annotations.json")
-            keys = list(filter(lambda k: k != 'filename', annotations[0].keys()))
-            paths = [f"{dataset}/{annotation['filename']}" for annotation in annotations]
-            labels = [annotation['label'] for annotation in annotations]
-        else:
-            [files, folders] = self.list_files(f"{dataset}/")
-            for folder in folders:
-                files = self.list_files(folder['path'])[0]
-                paths.extend([file['path'] for file in files])
-                labels.extend(len(files) * [folder['name']])
-        if shuffle:
-            ids = list(range(len(paths)))
-            random.shuffle(ids)
-            paths = [paths[id] for id in ids]
-            labels = [labels[id] for id in ids]
-        return paths, labels
-    
     
\ No newline at end of file
